summaryrefslogtreecommitdiff
path: root/src/libvirt-domain-checkpoint.c
diff options
context:
space:
mode:
authorDaniel P. Berrangé <berrange@redhat.com>2020-11-09 16:14:53 +0000
committerDaniel P. Berrangé <berrange@redhat.com>2020-11-09 16:29:06 +0000
commit2a917e6756578e43b21695aa284b39bdc05fa96f (patch)
tree972aec61e26ef4fa15cf5cdcf63e0e9d14022aaf /src/libvirt-domain-checkpoint.c
parentc8583f9cc0a89242bd7fec14b8d37d8f0f3d887c (diff)
downloadlibvirt-2a917e6756578e43b21695aa284b39bdc05fa96f.tar.gz
Fix name prefix of VIR_DOMAIN_CHECKPOINT_REDEFINE_VALIDATE
The enum constant names should all have a prefix that matches the enum name. VIR_DOMAIN_CHECKPOINT_REDEFINE_VALIDATE was missing the "CREATE_" part of the name prefix. Reviewed-by: Peter Krempa <pkrempa@redhat.com> Signed-off-by: Daniel P. Berrangé <berrange@redhat.com>
Diffstat (limited to 'src/libvirt-domain-checkpoint.c')
-rw-r--r--src/libvirt-domain-checkpoint.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/libvirt-domain-checkpoint.c b/src/libvirt-domain-checkpoint.c
index e0c2527ccb..e6ad4f4f5d 100644
--- a/src/libvirt-domain-checkpoint.c
+++ b/src/libvirt-domain-checkpoint.c
@@ -125,7 +125,7 @@ virDomainCheckpointGetConnect(virDomainCheckpointPtr checkpoint)
* has a way to resupply correct defaults). Not all hypervisors support
* this flag.
*
* If @flags includes VIR_DOMAIN_CHECKPOINT_REDEFINE_VALIDATE along with
* VIR_DOMAIN_CHECKPOINT_CREATE_REDEFINE the state of the metadata related
* to the disk state of the redefined checkpoint is validated. Note that
* hypervisors may require that the @domain is running to perform validation.
@@ -160,7 +160,7 @@ virDomainCheckpointCreateXML(virDomainPtr domain,
VIR_DOMAIN_CHECKPOINT_CREATE_QUIESCE,
error);
- VIR_REQUIRE_FLAG_GOTO(VIR_DOMAIN_CHECKPOINT_REDEFINE_VALIDATE,
+ VIR_REQUIRE_FLAG_GOTO(VIR_DOMAIN_CHECKPOINT_CREATE_REDEFINE_VALIDATE,
VIR_DOMAIN_CHECKPOINT_CREATE_REDEFINE,
error);
@@ -125,7 +125,7 @@ virDomainCheckpointGetConnect(virDomainCheckpointPtr checkpoint)
* this flag.
*
- * If @flags includes VIR_DOMAIN_CHECKPOINT_REDEFINE_VALIDATE along with
+ * If @flags includes VIR_DOMAIN_CHECKPOINT_CREATE_REDEFINE_VALIDATE along with
* VIR_DOMAIN_CHECKPOINT_CREATE_REDEFINE the state of the metadata related
* to the disk state of the redefined checkpoint is validated. Note that